When checking if a volume is mounted, search the deleted-volumes list as well
as the regular volumes list.

Apply with:
cd /usr/src/evms-2.2.2/
patch -p1 < is_mounted.patch
make
make install

--- evms-2.2.2a/engine/internalAPI.c	11 Nov 2003 21:53:35 -0000	1.114
+++ evms-2.2.2b/engine/internalAPI.c	28 Jan 2004 17:05:02 -0000
@@ -2469,7 +2469,47 @@
 		}
 
 	} else {
-		result = is_mounted(volume_name, 0, 0, mount_name);
+		/* Not found on VolumeList, check VolumeDeleteList. */
+		ADDRESS curr_obj;
+
+		/* Get current list pointer. */
+		GetHandle(VolumeDeleteList, &curr_obj);
+
+		GoToStartOfList(VolumeDeleteList);
+
+		/* Search the VolumeDeleteList for a volume whose name
+		 * matches volume_name.
+		 */
+		rc = GetObject(VolumeDeleteList,
+			       VOLUME_TAG,
+			       NULL,
+			       FALSE,
+			       (ADDRESS *) &vol);
+
+		while ((rc == DLIST_SUCCESS) && (vol != NULL) &&
+		       (strcmp(volume_name, vol->name) != 0)) {
+
+			rc = GetNextObject(VolumeDeleteList,
+					   VOLUME_TAG,
+					   (ADDRESS *) &vol);
+		}
+
+		if ((rc == DLIST_SUCCESS) && (vol != NULL)) {
+			/* Found the volume with the matching name. */
+			result = is_volume_mounted(vol);
+
+			if (result && (mount_name != NULL)) {
+				/* The caller wants a copy of the mount name. */
+				*mount_name = engine_strdup(vol->mount_point);
+			}
+
+		} else {
+			/* Not found on either list. */
+			result = is_mounted(volume_name, 0, 0, mount_name);
+		}
+
+		/* Restore current list pointer. */
+		GoToSpecifiedItem(VolumeDeleteList, curr_obj);
 	}
 
 	/* Restore current list pointer. */
